"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApiGatewayEnvelope = void 0;
const envelope_js_1 = require("./envelope.js");
const apigw_js_1 = require("../schemas/apigw.js");
const errors_js_1 = require("../errors.js");
/**
 * API Gateway envelope to extract data within body key
 */
class ApiGatewayEnvelope extends envelope_js_1.Envelope {
    static parse(data, schema) {
        return super.parse(apigw_js_1.APIGatewayProxyEventSchema.parse(data).body, schema);
    }
    static safeParse(data, schema) {
        const parsedEnvelope = apigw_js_1.APIGatewayProxyEventSchema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse ApiGatewayEnvelope', {
                    cause: parsedEnvelope.error,
                }),
                originalEvent: data,
            };
        }
        const parsedBody = super.safeParse(parsedEnvelope.data.body, schema);
        if (!parsedBody.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse ApiGatewayEnvelope body', {
                    cause: parsedBody.error,
                }),
                originalEvent: data,
            };
        }
        return parsedBody;
    }
}
exports.ApiGatewayEnvelope = ApiGatewayEnvelope;
