import { z } from 'zod';
import type { ParsedResult } from '../types/parser.js';
export declare class Envelope {
    /**
     * Abstract function to parse the content of the envelope using provided schema.
     * Both inputs are provided as unknown by the user.
     * We expect the data to be either string that can be parsed to json or object.
     * @internal
     * @param data data to parse
     * @param schema schema
     */
    static readonly parse: <T extends z.ZodType<any, z.ZodTypeDef, any>>(data: unknown, schema: T) => z.infer<T>;
    /**
     * Abstract function to safely parse the content of the envelope using provided schema.
     * safeParse is used to avoid throwing errors, thus we catuch all errors and wrap them in the result.
     * @param input
     * @param schema
     */
    static readonly safeParse: <T extends z.ZodType<any, z.ZodTypeDef, any>>(input: unknown, schema: T) => ParsedResult<unknown, z.infer<T>>;
}
//# sourceMappingURL=envelope.d.ts.map