"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EventBridgeEnvelope = void 0;
const envelope_js_1 = require("./envelope.js");
const index_js_1 = require("../schemas/index.js");
const errors_js_1 = require("../errors.js");
/**
 * Envelope for EventBridge schema that extracts and parses data from the `detail` key.
 */
class EventBridgeEnvelope extends envelope_js_1.Envelope {
    static parse(data, schema) {
        return super.parse(index_js_1.EventBridgeSchema.parse(data).detail, schema);
    }
    static safeParse(data, schema) {
        const parsedEnvelope = index_js_1.EventBridgeSchema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse EventBridge envelope', {
                    cause: parsedEnvelope.error,
                }),
                originalEvent: data,
            };
        }
        const parsedDetail = super.safeParse(parsedEnvelope.data.detail, schema);
        if (!parsedDetail.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse EventBridge envelope detail', {
                    cause: parsedDetail.error,
                }),
                originalEvent: data,
            };
        }
        return parsedDetail;
    }
}
exports.EventBridgeEnvelope = EventBridgeEnvelope;
