"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LambdaFunctionUrlEnvelope = void 0;
const envelope_js_1 = require("./envelope.js");
const index_js_1 = require("../schemas/index.js");
const errors_js_1 = require("../errors.js");
/**
 * Lambda function URL envelope to extract data within body key
 */
class LambdaFunctionUrlEnvelope extends envelope_js_1.Envelope {
    static parse(data, schema) {
        const parsedEnvelope = index_js_1.LambdaFunctionUrlSchema.parse(data);
        if (!parsedEnvelope.body) {
            throw new Error('Body field of Lambda function URL event is undefined');
        }
        return super.parse(parsedEnvelope.body, schema);
    }
    static safeParse(data, schema) {
        const parsedEnvelope = index_js_1.LambdaFunctionUrlSchema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse Lambda function URL envelope'),
                originalEvent: data,
            };
        }
        const parsedBody = super.safeParse(parsedEnvelope.data.body, schema);
        if (!parsedBody.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse Lambda function URL body', {
                    cause: parsedBody.error,
                }),
                originalEvent: data,
            };
        }
        return parsedBody;
    }
}
exports.LambdaFunctionUrlEnvelope = LambdaFunctionUrlEnvelope;
