"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VpcLatticeV2Envelope = void 0;
const envelope_js_1 = require("./envelope.js");
const index_js_1 = require("../schemas/index.js");
const errors_js_1 = require("../errors.js");
/**
 * Amazon VPC Lattice envelope to extract data within body key
 */
class VpcLatticeV2Envelope extends envelope_js_1.Envelope {
    static parse(data, schema) {
        const parsedEnvelope = index_js_1.VpcLatticeV2Schema.parse(data);
        return super.parse(parsedEnvelope.body, schema);
    }
    static safeParse(data, schema) {
        const parsedEnvelope = index_js_1.VpcLatticeV2Schema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse VpcLatticeV2 envelope.', {
                    cause: parsedEnvelope.error,
                }),
                originalEvent: data,
            };
        }
        const parsedBody = super.safeParse(parsedEnvelope.data.body, schema);
        if (!parsedBody.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse VpcLatticeV2 body.', {
                    cause: parsedBody.error,
                }),
                originalEvent: data,
            };
        }
        return parsedBody;
    }
}
exports.VpcLatticeV2Envelope = VpcLatticeV2Envelope;
