import { APIGatewayProxyEventV2Schema } from '../schemas/apigwv2.js';
import { Envelope } from './envelope.js';
import { ParseError } from '../errors.js';
/**
 * API Gateway V2 envelope to extract data within body key
 */
export class ApiGatewayV2Envelope extends Envelope {
    static parse(data, schema) {
        return super.parse(APIGatewayProxyEventV2Schema.parse(data).body, schema);
    }
    static safeParse(data, schema) {
        const parsedEnvelope = APIGatewayProxyEventV2Schema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new ParseError('Failed to parse API Gateway V2 envelope', {
                    cause: parsedEnvelope.error,
                }),
                originalEvent: data,
            };
        }
        const parsedBody = super.safeParse(parsedEnvelope.data.body, schema);
        if (!parsedBody.success) {
            return {
                success: false,
                error: new ParseError('Failed to parse API Gateway V2 envelope body', {
                    cause: parsedBody.error,
                }),
                originalEvent: data,
            };
        }
        return parsedBody;
    }
}
