import { Envelope } from './envelope.js';
import { EventBridgeSchema } from '../schemas/index.js';
import { ParseError } from '../errors.js';
/**
 * Envelope for EventBridge schema that extracts and parses data from the `detail` key.
 */
export class EventBridgeEnvelope extends Envelope {
    static parse(data, schema) {
        return super.parse(EventBridgeSchema.parse(data).detail, schema);
    }
    static safeParse(data, schema) {
        const parsedEnvelope = EventBridgeSchema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new ParseError('Failed to parse EventBridge envelope', {
                    cause: parsedEnvelope.error,
                }),
                originalEvent: data,
            };
        }
        const parsedDetail = super.safeParse(parsedEnvelope.data.detail, schema);
        if (!parsedDetail.success) {
            return {
                success: false,
                error: new ParseError('Failed to parse EventBridge envelope detail', {
                    cause: parsedDetail.error,
                }),
                originalEvent: data,
            };
        }
        return parsedDetail;
    }
}
